@@ -1,6 +1,7 @@
 package Rose::DB::Pg;
 
 use strict;
+no warnings 'uninitialized';
 
 use DateTime::Infinite;
 use DateTime::Format::Pg;
@@ -10,6 +11,8 @@ use Rose::DB;
 
 our $VERSION = '0.786'; # overshot version number, freeze until caught up
 
+use constant DBD_PG_AFTER_380 => ($DBD::Pg::VERSION =~ /^(\d+)\.(\d+)/ && ($1 >=3 && $2 >= 8)) ? 1 : 0;
+
 our $Debug = 0;
 
 #
@@ -665,6 +668,17 @@ sub parse_dbi_column_info_default
   return $string;
 }
 
+sub refine_dbi_foreign_key_info
+{
+  my($self, $fk_info) = @_;
+
+  if(DBD_PG_AFTER_380)
+  {
+    $fk_info->{'FK_TABLE_CAT'} = undef;
+    $fk_info->{'UK_TABLE_CAT'} = undef;
+  }
+}
+
 sub list_tables
 {
   my($self, %args) = @_;
